/*
 * Name:    MpMtr.c
 *
 * Purpose: Python module for accessing 'mxmotor' commands from scripts
 *          run by the 'python.mxo' MX dynamically loadable extension.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2015 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "mp.h"
#include "MpMtr.h"

#include "mx_dynamic_library.h"

/* Method table for the MpMtr module. */

static PyMethodDef MpMtrMethods[] = {
	{ "init",
			MpMtr_init_cmd,
			METH_VARARGS },
	{ NULL, NULL }
};

/* Private variables for the MpMtr module. */

static MX_DYNAMIC_LIBRARY *main_program = NULL;

static MX_RECORD *motor_record_list = NULL;

static int (*cmd_run_command_fn)( char * ) = NULL;

/* This is MpMtr's module initialization function. */

MX_EXPORT void
initMpMtr( void )
{
	MX_DEBUG(-2,("MpMtr initialization function called."));

	/* Initialize the module. */

	(void) Py_InitModule("MpMtr", MpMtrMethods);
}

/*--------------------------------------------------------------------------*/

MX_EXPORT PyObject *
MpMtr_init_cmd( PyObject *self, PyObject *args )
{
	static const char fname[] = "MpMtr.init()";

	void *motor_record_list_ptr;
	void *cmd_run_command_ptr;
	mx_status_type mx_status;

	MX_DEBUG(-2,("%s invoked.", fname));

	/* Get an MX dynamic library pointer for the main program
	 * by passing NULL as the name of the library.
	 */

	mx_status = mx_dynamic_library_open( NULL, &main_program, 0 );

	if ( mx_status.code != MXE_SUCCESS )
		return Py_None;

	MX_DEBUG(-2,("%s: main_program = %p", fname, main_program));

	/* Look for the 'motor_record_list' variable in the main program. */

	mx_status = mx_dynamic_library_find_symbol( main_program,
						"motor_record_list",
						&motor_record_list_ptr, FALSE );

	motor_record_list = motor_record_list_ptr;

	MX_DEBUG(-2,("%s: motor_record_list = %p", fname, motor_record_list));

	/* Look for the 'mxmotor' function for running a single command. */

	mx_status = mx_dynamic_library_find_symbol( main_program,
						"cmd_run_command",
						&cmd_run_command_ptr, FALSE );

	cmd_run_command_fn = cmd_run_command_ptr;

	MX_DEBUG(-2,("%s: cmd_run_command_fn = %p", fname, cmd_run_command_fn));

	return Py_None;
}

